//Source file: AccessTechnology.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Defines the derived access technology utilised by the user.
 *
 */
public final class AccessTechnology implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static AccessTechnology[] _array = new AccessTechnology[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private AccessTechnology(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Access via packet switched connection in mobile network
     */
    public static final int _MOBILE_ACCESS_PS =  0;

    /**
     * Access via packet switched connection in mobile network
     */
    public static final AccessTechnology MOBILE_ACCESS_PS = new AccessTechnology(_MOBILE_ACCESS_PS);

    /**
     * Access via a circuit switched connection in mobile network
     */
    public static final int _MOBILE_ACCESS_CS =  1;

    /**
     * Access via a circuit switched connection in mobile network
     */
    public static final AccessTechnology MOBILE_ACCESS_CS = new AccessTechnology(_MOBILE_ACCESS_CS);

    /**
     * Access via a fixed network
     */
    public static final int _FIXED_ACCESS =  2;

    /**
     * Access via a fixed network
     */
    public static final AccessTechnology FIXED_ACCESS = new AccessTechnology(_FIXED_ACCESS);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved AccessTechnology object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the AccessTechnology object
     */
    public String getValueText() {
        switch (_value) {
            case _MOBILE_ACCESS_PS:
                return "MOBILE_ACCESS_PS";
            case _MOBILE_ACCESS_CS:
                return "MOBILE_ACCESS_CS";
            case _FIXED_ACCESS:
                return "FIXED_ACCESS";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static AccessTechnology getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof AccessTechnology)) {
            return false;
        }
        AccessTechnology accessTechnology = (AccessTechnology) o; 
        if(!(this.getValue() == accessTechnology.getValue())) {
            return false;
        }
        if (this.hashCode() != accessTechnology.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AccessTechnology

