//Source file: AuthStatusIndicator.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Used to indicate if and how the user has been authenticated during data session establishment.
 *
 */
public final class AuthStatusIndicator implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static AuthStatusIndicator[] _array = new AuthStatusIndicator[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private AuthStatusIndicator(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Authenticated only for the network.
     */
    public static final int _AUTHENTICATED_FOR_NETWORK_ONLY =  0;

    /**
     * Authenticated only for the network.
     */
    public static final AuthStatusIndicator AUTHENTICATED_FOR_NETWORK_ONLY = new AuthStatusIndicator(_AUTHENTICATED_FOR_NETWORK_ONLY);

    /**
     * Authenticated for the network and IP services
     */
    public static final int _AUTHENTICATED_FOR_NETWORK_AND_IP_SERVICES =  1;

    /**
     * Authenticated for the network and IP services
     */
    public static final AuthStatusIndicator AUTHENTICATED_FOR_NETWORK_AND_IP_SERVICES = new AuthStatusIndicator(_AUTHENTICATED_FOR_NETWORK_AND_IP_SERVICES);

    /**
     * Not authenticated
     */
    public static final int _NOT_AUTHENTICATED =  2;

    /**
     * Not authenticated
     */
    public static final AuthStatusIndicator NOT_AUTHENTICATED = new AuthStatusIndicator(_NOT_AUTHENTICATED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved AuthStatusIndicator object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the AuthStatusIndicator object
     */
    public String getValueText() {
        switch (_value) {
            case _AUTHENTICATED_FOR_NETWORK_ONLY:
                return "AUTHENTICATED_FOR_NETWORK_ONLY";
            case _AUTHENTICATED_FOR_NETWORK_AND_IP_SERVICES:
                return "AUTHENTICATED_FOR_NETWORK_AND_IP_SERVICES";
            case _NOT_AUTHENTICATED:
                return "NOT_AUTHENTICATED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static AuthStatusIndicator getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof AuthStatusIndicator)) {
            return false;
        }
        AuthStatusIndicator authStatusIndicator = (AuthStatusIndicator) o; 
        if(!(this.getValue() == authStatusIndicator.getValue())) {
            return false;
        }
        if (this.hashCode() != authStatusIndicator.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AuthStatusIndicator

