//Source file: BindingEntryType.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Defines the type of binding information. 
 *
 */
public final class BindingEntryType implements java.io.Serializable {

    private int _value;
    private static int _size = 4;
    private static BindingEntryType[] _array = new BindingEntryType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private BindingEntryType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined
     */
    public static final int _UB_UNDEFINED =  0;

    /**
     * Undefined
     */
    public static final BindingEntryType UB_UNDEFINED = new BindingEntryType(_UB_UNDEFINED);

    /**
     * A number indicating the number of seconds the binding is valid
     */
    public static final int _UB_EXPIRES =  1;

    /**
     * A number indicating the number of seconds the binding is valid
     */
    public static final BindingEntryType UB_EXPIRES = new BindingEntryType(_UB_EXPIRES);

    /**
     * The address representing the user's contact address
     */
    public static final int _UB_CONTACT_ADDRESS =  2;

    /**
     * The address representing the user's contact address
     */
    public static final BindingEntryType UB_CONTACT_ADDRESS = new BindingEntryType(_UB_CONTACT_ADDRESS);

    /**
     * A number between 0 and 1 indicating the contact address' relative preference
     */
    public static final int _UB_PREFERENCE =  3;

    /**
     * A number between 0 and 1 indicating the contact address' relative preference
     */
    public static final BindingEntryType UB_PREFERENCE = new BindingEntryType(_UB_PREFERENCE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved BindingEntryType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the BindingEntryType object
     */
    public String getValueText() {
        switch (_value) {
            case _UB_UNDEFINED:
                return "UB_UNDEFINED";
            case _UB_EXPIRES:
                return "UB_EXPIRES";
            case _UB_CONTACT_ADDRESS:
                return "UB_CONTACT_ADDRESS";
            case _UB_PREFERENCE:
                return "UB_PREFERENCE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static BindingEntryType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof BindingEntryType)) {
            return false;
        }
        BindingEntryType bindingEntryType = (BindingEntryType) o; 
        if(!(this.getValue() == bindingEntryType.getValue())) {
            return false;
        }
        if (this.hashCode() != bindingEntryType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // BindingEntryType

