//Source file: GeographicalPosition.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Defines the Sequence of Data Elements that specify a geographical position.
The horizontal location is defined by an 'ellipsoid point with uncertainty shape'. The reference system chosen for the coding of locations is the World Geodetic System 1984 (WGS 84).
TypeOfUncertaintyShape describes the type of the uncertainty shape and Longitude/Latitude defines the position of the uncertainty shape. 
 * 
 */
public final class GeographicalPosition implements java.io.Serializable {

    private float longitude;
    private float latitude;
    private org.csapi.jr.se.mm.LocationUncertaintyShape typeOfUncertaintyShape;
    private float uncertaintyInnerSemiMajor;
    private float uncertaintyOuterSemiMajor;
    private float uncertaintyInnerSemiMinor;
    private float uncertaintyOuterSemiMinor;
    private int angleOfSemiMajor;
    private int segmentStartAngle;
    private int segmentEndAngle;

    /**
     * Creates a new GeographicalPosition instance.
     */
    public GeographicalPosition () {}

    /**
     * Creates a new GeographicalPosition instance.
     * @param _longitude   Longitude of the position used in the trigger.
     * @param _latitude   Latitude of the position used in the trigger.
     * @param _typeOfUncertaintyShape   
     * @param _uncertaintyInnerSemiMajor   See description of an Ellipse Arc in the documentation
     * @param _uncertaintyOuterSemiMajor   See description of an Ellipse Arc in the documentation
     * @param _uncertaintyInnerSemiMinor   See description of an Ellipse Arc in the documentation
     * @param _uncertaintyOuterSemiMinor   See description of an Ellipse Arc in the documentation
     * @param _angleOfSemiMajor   Angle of the semi major of the ellipse area used in the trigger.
     * @param _segmentStartAngle   See description of an Ellipse Arc in the documentation
     * @param _segmentEndAngle   See description of an Ellipse Arc in the documentation
     */
    public GeographicalPosition (float _longitude, float _latitude, org.csapi.jr.se.mm.LocationUncertaintyShape _typeOfUncertaintyShape, float _uncertaintyInnerSemiMajor, float _uncertaintyOuterSemiMajor, float _uncertaintyInnerSemiMinor, float _uncertaintyOuterSemiMinor, int _angleOfSemiMajor, int _segmentStartAngle, int _segmentEndAngle) {

        this.longitude = _longitude;
        this.latitude = _latitude;
        this.typeOfUncertaintyShape = _typeOfUncertaintyShape;
        this.uncertaintyInnerSemiMajor = _uncertaintyInnerSemiMajor;
        this.uncertaintyOuterSemiMajor = _uncertaintyOuterSemiMajor;
        this.uncertaintyInnerSemiMinor = _uncertaintyInnerSemiMinor;
        this.uncertaintyOuterSemiMinor = _uncertaintyOuterSemiMinor;
        this.angleOfSemiMajor = _angleOfSemiMajor;
        this.segmentStartAngle = _segmentStartAngle;
        this.segmentEndAngle = _segmentEndAngle;
    }

    /**
     * This method returns a longitude.
     * 
     * @return a float value
     */
    public float getLongitude() {
        return longitude;
    }

    /**
     * This method returns a latitude.
     * 
     * @return a float value
     */
    public float getLatitude() {
        return latitude;
    }

    /**
     * This method returns a typeOfUncertaintyShape.
     * 
     * @return a org.csapi.jr.se.mm.LocationUncertaintyShape value
     */
    public org.csapi.jr.se.mm.LocationUncertaintyShape getTypeOfUncertaintyShape() {
        return typeOfUncertaintyShape;
    }

    /**
     * This method returns a uncertaintyInnerSemiMajor.
     * 
     * @return a float value
     */
    public float getUncertaintyInnerSemiMajor() {
        return uncertaintyInnerSemiMajor;
    }

    /**
     * This method returns a uncertaintyOuterSemiMajor.
     * 
     * @return a float value
     */
    public float getUncertaintyOuterSemiMajor() {
        return uncertaintyOuterSemiMajor;
    }

    /**
     * This method returns a uncertaintyInnerSemiMinor.
     * 
     * @return a float value
     */
    public float getUncertaintyInnerSemiMinor() {
        return uncertaintyInnerSemiMinor;
    }

    /**
     * This method returns a uncertaintyOuterSemiMinor.
     * 
     * @return a float value
     */
    public float getUncertaintyOuterSemiMinor() {
        return uncertaintyOuterSemiMinor;
    }

    /**
     * This method returns a angleOfSemiMajor.
     * 
     * @return a int value
     */
    public int getAngleOfSemiMajor() {
        return angleOfSemiMajor;
    }

    /**
     * This method returns a segmentStartAngle.
     * 
     * @return a int value
     */
    public int getSegmentStartAngle() {
        return segmentStartAngle;
    }

    /**
     * This method returns a segmentEndAngle.
     * 
     * @return a int value
     */
    public int getSegmentEndAngle() {
        return segmentEndAngle;
    }


    /**
     * This method sets a longitude.
     */ 
    public void setLongitude(float longitude) {
        this.longitude = longitude;
    }

    /**
     * This method sets a latitude.
     */ 
    public void setLatitude(float latitude) {
        this.latitude = latitude;
    }

    /**
     * This method sets a typeOfUncertaintyShape.
     */ 
    public void setTypeOfUncertaintyShape(org.csapi.jr.se.mm.LocationUncertaintyShape typeOfUncertaintyShape) {
        this.typeOfUncertaintyShape = typeOfUncertaintyShape;
    }

    /**
     * This method sets a uncertaintyInnerSemiMajor.
     */ 
    public void setUncertaintyInnerSemiMajor(float uncertaintyInnerSemiMajor) {
        this.uncertaintyInnerSemiMajor = uncertaintyInnerSemiMajor;
    }

    /**
     * This method sets a uncertaintyOuterSemiMajor.
     */ 
    public void setUncertaintyOuterSemiMajor(float uncertaintyOuterSemiMajor) {
        this.uncertaintyOuterSemiMajor = uncertaintyOuterSemiMajor;
    }

    /**
     * This method sets a uncertaintyInnerSemiMinor.
     */ 
    public void setUncertaintyInnerSemiMinor(float uncertaintyInnerSemiMinor) {
        this.uncertaintyInnerSemiMinor = uncertaintyInnerSemiMinor;
    }

    /**
     * This method sets a uncertaintyOuterSemiMinor.
     */ 
    public void setUncertaintyOuterSemiMinor(float uncertaintyOuterSemiMinor) {
        this.uncertaintyOuterSemiMinor = uncertaintyOuterSemiMinor;
    }

    /**
     * This method sets a angleOfSemiMajor.
     */ 
    public void setAngleOfSemiMajor(int angleOfSemiMajor) {
        this.angleOfSemiMajor = angleOfSemiMajor;
    }

    /**
     * This method sets a segmentStartAngle.
     */ 
    public void setSegmentStartAngle(int segmentStartAngle) {
        this.segmentStartAngle = segmentStartAngle;
    }

    /**
     * This method sets a segmentEndAngle.
     */ 
    public void setSegmentEndAngle(int segmentEndAngle) {
        this.segmentEndAngle = segmentEndAngle;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof GeographicalPosition)) {
            return false;
        } 
        GeographicalPosition geographicalPosition = (GeographicalPosition) o;
        if(!(this.longitude == geographicalPosition.longitude)) {
            return false;
        }
        if(!(this.latitude == geographicalPosition.latitude)) {
            return false;
        }
        if ((this.typeOfUncertaintyShape != null) && (geographicalPosition.typeOfUncertaintyShape != null)) {
            if(!(this.typeOfUncertaintyShape.equals(geographicalPosition.typeOfUncertaintyShape))) {
                return false;
            }
        }
        if(!(this.uncertaintyInnerSemiMajor == geographicalPosition.uncertaintyInnerSemiMajor)) {
            return false;
        }
        if(!(this.uncertaintyOuterSemiMajor == geographicalPosition.uncertaintyOuterSemiMajor)) {
            return false;
        }
        if(!(this.uncertaintyInnerSemiMinor == geographicalPosition.uncertaintyInnerSemiMinor)) {
            return false;
        }
        if(!(this.uncertaintyOuterSemiMinor == geographicalPosition.uncertaintyOuterSemiMinor)) {
            return false;
        }
        if(!(this.angleOfSemiMajor == geographicalPosition.angleOfSemiMajor)) {
            return false;
        }
        if(!(this.segmentStartAngle == geographicalPosition.segmentStartAngle)) {
            return false;
        }
        if(!(this.segmentEndAngle == geographicalPosition.segmentEndAngle)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // GeographicalPosition

