//Source file: LocationRequest.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Defines the Sequence of Data Elements that specify a location request.
 * 
 */
public final class LocationRequest implements java.io.Serializable {

    private float requestedAccuracy;
    private org.csapi.jr.se.mm.LocationResponseTime requestedResponseTime;
    private boolean altitudeRequested;
    private org.csapi.jr.se.mm.LocationType type;
    private org.csapi.jr.se.mm.LocationPriority priority;
    private String requestedLocationMethod;

    /**
     * Creates a new LocationRequest instance.
     */
    public LocationRequest () {}

    /**
     * Creates a new LocationRequest instance.
     * @param _requestedAccuracy   Requested accuracy in meters.
     * @param _requestedResponseTime   Requested response time as a classified requirement or as an absolute timer. 
     * @param _altitudeRequested   Altitude request flag. 
     * @param _type   The kind of location that is requested. 
     * @param _priority   Priority of location request. 
     * @param _requestedLocationMethod   The kind of location method that is requested. 
     */
    public LocationRequest (float _requestedAccuracy, org.csapi.jr.se.mm.LocationResponseTime _requestedResponseTime, boolean _altitudeRequested, org.csapi.jr.se.mm.LocationType _type, org.csapi.jr.se.mm.LocationPriority _priority, String _requestedLocationMethod) {

        this.requestedAccuracy = _requestedAccuracy;
        this.requestedResponseTime = _requestedResponseTime;
        this.altitudeRequested = _altitudeRequested;
        this.type = _type;
        this.priority = _priority;
        this.requestedLocationMethod = _requestedLocationMethod;
    }

    /**
     * This method returns a requestedAccuracy.
     * 
     * @return a float value
     */
    public float getRequestedAccuracy() {
        return requestedAccuracy;
    }

    /**
     * This method returns a requestedResponseTime.
     * 
     * @return a org.csapi.jr.se.mm.LocationResponseTime value
     */
    public org.csapi.jr.se.mm.LocationResponseTime getRequestedResponseTime() {
        return requestedResponseTime;
    }

    /**
     * This method returns a altitudeRequested.
     * 
     * @return a boolean value
     */
    public boolean getAltitudeRequested() {
        return altitudeRequested;
    }

    /**
     * This method returns a type.
     * 
     * @return a org.csapi.jr.se.mm.LocationType value
     */
    public org.csapi.jr.se.mm.LocationType getType() {
        return type;
    }

    /**
     * This method returns a priority.
     * 
     * @return a org.csapi.jr.se.mm.LocationPriority value
     */
    public org.csapi.jr.se.mm.LocationPriority getPriority() {
        return priority;
    }

    /**
     * This method returns a requestedLocationMethod.
     * 
     * @return a String value
     */
    public String getRequestedLocationMethod() {
        return requestedLocationMethod;
    }


    /**
     * This method sets a requestedAccuracy.
     */ 
    public void setRequestedAccuracy(float requestedAccuracy) {
        this.requestedAccuracy = requestedAccuracy;
    }

    /**
     * This method sets a requestedResponseTime.
     */ 
    public void setRequestedResponseTime(org.csapi.jr.se.mm.LocationResponseTime requestedResponseTime) {
        this.requestedResponseTime = requestedResponseTime;
    }

    /**
     * This method sets a altitudeRequested.
     */ 
    public void setAltitudeRequested(boolean altitudeRequested) {
        this.altitudeRequested = altitudeRequested;
    }

    /**
     * This method sets a type.
     */ 
    public void setType(org.csapi.jr.se.mm.LocationType type) {
        this.type = type;
    }

    /**
     * This method sets a priority.
     */ 
    public void setPriority(org.csapi.jr.se.mm.LocationPriority priority) {
        this.priority = priority;
    }

    /**
     * This method sets a requestedLocationMethod.
     */ 
    public void setRequestedLocationMethod(String requestedLocationMethod) {
        this.requestedLocationMethod = requestedLocationMethod;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof LocationRequest)) {
            return false;
        } 
        LocationRequest locationRequest = (LocationRequest) o;
        if ((this.requestedLocationMethod != null) && (locationRequest.requestedLocationMethod != null)) {
            if(!(this.requestedLocationMethod.equals(locationRequest.requestedLocationMethod)))  {
                return false;
            }
        }
        if(!(this.requestedAccuracy == locationRequest.requestedAccuracy)) {
            return false;
        }
        if ((this.requestedResponseTime != null) && (locationRequest.requestedResponseTime != null)) {
            if(!(this.requestedResponseTime.equals(locationRequest.requestedResponseTime))) {
                return false;
            }
        }
        if(!(this.altitudeRequested == locationRequest.altitudeRequested)) {
            return false;
        }
        if ((this.type != null) && (locationRequest.type != null)) {
            if(!(this.type.equals(locationRequest.type))) {
                return false;
            }
        }
        if ((this.priority != null) && (locationRequest.priority != null)) {
            if(!(this.priority.equals(locationRequest.priority))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LocationRequest

