//Source file: LocationResponseIndicator.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Defines a response time requirement.
 *
 */
public final class LocationResponseIndicator implements java.io.Serializable {

    private int _value;
    private static int _size = 4;
    private static LocationResponseIndicator[] _array = new LocationResponseIndicator[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private LocationResponseIndicator(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * No delay: return either initial or last known location of the user.
     */
    public static final int _M_NO_DELAY =  0;

    /**
     * No delay: return either initial or last known location of the user.
     */
    public static final LocationResponseIndicator M_NO_DELAY = new LocationResponseIndicator(_M_NO_DELAY);

    /**
     * Low delay: return the current location with minimum delay. The mobility service shall attempt to fulfil any accuracy requirement, but in doing so shall not add any additional delay.
     */
    public static final int _M_LOW_DELAY =  1;

    /**
     * Low delay: return the current location with minimum delay. The mobility service shall attempt to fulfil any accuracy requirement, but in doing so shall not add any additional delay.
     */
    public static final LocationResponseIndicator M_LOW_DELAY = new LocationResponseIndicator(_M_LOW_DELAY);

    /**
     * Delay tolerant: obtain the current location with regard to fulfilling the accuracy requirement.
     */
    public static final int _M_DELAY_TOLERANT =  2;

    /**
     * Delay tolerant: obtain the current location with regard to fulfilling the accuracy requirement.
     */
    public static final LocationResponseIndicator M_DELAY_TOLERANT = new LocationResponseIndicator(_M_DELAY_TOLERANT);

    /**
     * Use timer value: obtain the current location with regard to fulfilling the response time requirement.
     */
    public static final int _M_USE_TIMER_VALUE =  3;

    /**
     * Use timer value: obtain the current location with regard to fulfilling the response time requirement.
     */
    public static final LocationResponseIndicator M_USE_TIMER_VALUE = new LocationResponseIndicator(_M_USE_TIMER_VALUE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved LocationResponseIndicator object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the LocationResponseIndicator object
     */
    public String getValueText() {
        switch (_value) {
            case _M_NO_DELAY:
                return "M_NO_DELAY";
            case _M_LOW_DELAY:
                return "M_LOW_DELAY";
            case _M_DELAY_TOLERANT:
                return "M_DELAY_TOLERANT";
            case _M_USE_TIMER_VALUE:
                return "M_USE_TIMER_VALUE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static LocationResponseIndicator getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof LocationResponseIndicator)) {
            return false;
        }
        LocationResponseIndicator locationResponseIndicator = (LocationResponseIndicator) o; 
        if(!(this.getValue() == locationResponseIndicator.getValue())) {
            return false;
        }
        if (this.hashCode() != locationResponseIndicator.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LocationResponseIndicator

