//Source file: MobilityDiagnostic.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Defines a diagnostic value that is reported in addition to an error by one of the mobility services.
 *
 */
public final class MobilityDiagnostic implements java.io.Serializable {

    private int _value;
    private static int _size = 12;
    private static MobilityDiagnostic[] _array = new MobilityDiagnostic[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private MobilityDiagnostic(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * No diagnostic information present. Valid for all type of errors.
     */
    public static final int _M_NO_INFORMATION =  0;

    /**
     * No diagnostic information present. Valid for all type of errors.
     */
    public static final MobilityDiagnostic M_NO_INFORMATION = new MobilityDiagnostic(_M_NO_INFORMATION);

    /**
     * Application not in privacy exception list.
Valid for 'Unauthorised Application' error.
     */
    public static final int _M_APPL_NOT_IN_PRIV_EXCEPT_LST =  1;

    /**
     * Application not in privacy exception list.
Valid for 'Unauthorised Application' error.
     */
    public static final MobilityDiagnostic M_APPL_NOT_IN_PRIV_EXCEPT_LST = new MobilityDiagnostic(_M_APPL_NOT_IN_PRIV_EXCEPT_LST);

    /**
     * Call to user not set-up.
Valid for 'Unauthorised Application' error.
     */
    public static final int _M_CALL_TO_USER_NOT_SETUP =  2;

    /**
     * Call to user not set-up.
Valid for 'Unauthorised Application' error.
     */
    public static final MobilityDiagnostic M_CALL_TO_USER_NOT_SETUP = new MobilityDiagnostic(_M_CALL_TO_USER_NOT_SETUP);

    /**
     * Privacy override not applicable.
Valid for 'Unauthorised Application' error.
     */
    public static final int _M_PRIVACY_OVERRIDE_NOT_APPLIC =  3;

    /**
     * Privacy override not applicable.
Valid for 'Unauthorised Application' error.
     */
    public static final MobilityDiagnostic M_PRIVACY_OVERRIDE_NOT_APPLIC = new MobilityDiagnostic(_M_PRIVACY_OVERRIDE_NOT_APPLIC);

    /**
     * Disallowed by local regulatory requirements.
Valid for 'Unauthorised Application' error.
     */
    public static final int _M_DISALL_BY_LOCAL_REGULAT_REQ =  4;

    /**
     * Disallowed by local regulatory requirements.
Valid for 'Unauthorised Application' error.
     */
    public static final MobilityDiagnostic M_DISALL_BY_LOCAL_REGULAT_REQ = new MobilityDiagnostic(_M_DISALL_BY_LOCAL_REGULAT_REQ);

    /**
     * Congestion.
Valid for 'Position Method Failure' error.
     */
    public static final int _M_CONGESTION =  5;

    /**
     * Congestion.
Valid for 'Position Method Failure' error.
     */
    public static final MobilityDiagnostic M_CONGESTION = new MobilityDiagnostic(_M_CONGESTION);

    /**
     * Insufficient resources. 
Valid for 'Position Method Failure' error.
     */
    public static final int _M_INSUFFICIENT_RESOURCES =  6;

    /**
     * Insufficient resources. 
Valid for 'Position Method Failure' error.
     */
    public static final MobilityDiagnostic M_INSUFFICIENT_RESOURCES = new MobilityDiagnostic(_M_INSUFFICIENT_RESOURCES);

    /**
     * Insufficient measurement data. 
Valid for 'Position Method Failure' error.
     */
    public static final int _M_INSUFFICIENT_MEAS_DATA =  7;

    /**
     * Insufficient measurement data. 
Valid for 'Position Method Failure' error.
     */
    public static final MobilityDiagnostic M_INSUFFICIENT_MEAS_DATA = new MobilityDiagnostic(_M_INSUFFICIENT_MEAS_DATA);

    /**
     * Inconsistent measurement data. 
Valid for 'Position Method Failure' error.
     */
    public static final int _M_INCONSISTENT_MEAS_DATA =  8;

    /**
     * Inconsistent measurement data. 
Valid for 'Position Method Failure' error.
     */
    public static final MobilityDiagnostic M_INCONSISTENT_MEAS_DATA = new MobilityDiagnostic(_M_INCONSISTENT_MEAS_DATA);

    /**
     * Location procedure not completed. 
Valid for 'Position Method Failure' error.
     */
    public static final int _M_LOC_PROC_NOT_COMPLETED =  9;

    /**
     * Location procedure not completed. 
Valid for 'Position Method Failure' error.
     */
    public static final MobilityDiagnostic M_LOC_PROC_NOT_COMPLETED = new MobilityDiagnostic(_M_LOC_PROC_NOT_COMPLETED);

    /**
     * Location procedure not supported by user. 
Valid for 'Position Method Failure' error.
     */
    public static final int _M_LOC_PROC_NOT_SUPP_BY_USER =  10;

    /**
     * Location procedure not supported by user. 
Valid for 'Position Method Failure' error.
     */
    public static final MobilityDiagnostic M_LOC_PROC_NOT_SUPP_BY_USER = new MobilityDiagnostic(_M_LOC_PROC_NOT_SUPP_BY_USER);

    /**
     * Quality of service not attainable. 
Valid for 'Position Method Failure' error.
     */
    public static final int _M_QOS_NOT_ATTAINABLE =  11;

    /**
     * Quality of service not attainable. 
Valid for 'Position Method Failure' error.
     */
    public static final MobilityDiagnostic M_QOS_NOT_ATTAINABLE = new MobilityDiagnostic(_M_QOS_NOT_ATTAINABLE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved MobilityDiagnostic object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the MobilityDiagnostic object
     */
    public String getValueText() {
        switch (_value) {
            case _M_NO_INFORMATION:
                return "M_NO_INFORMATION";
            case _M_APPL_NOT_IN_PRIV_EXCEPT_LST:
                return "M_APPL_NOT_IN_PRIV_EXCEPT_LST";
            case _M_CALL_TO_USER_NOT_SETUP:
                return "M_CALL_TO_USER_NOT_SETUP";
            case _M_PRIVACY_OVERRIDE_NOT_APPLIC:
                return "M_PRIVACY_OVERRIDE_NOT_APPLIC";
            case _M_DISALL_BY_LOCAL_REGULAT_REQ:
                return "M_DISALL_BY_LOCAL_REGULAT_REQ";
            case _M_CONGESTION:
                return "M_CONGESTION";
            case _M_INSUFFICIENT_RESOURCES:
                return "M_INSUFFICIENT_RESOURCES";
            case _M_INSUFFICIENT_MEAS_DATA:
                return "M_INSUFFICIENT_MEAS_DATA";
            case _M_INCONSISTENT_MEAS_DATA:
                return "M_INCONSISTENT_MEAS_DATA";
            case _M_LOC_PROC_NOT_COMPLETED:
                return "M_LOC_PROC_NOT_COMPLETED";
            case _M_LOC_PROC_NOT_SUPP_BY_USER:
                return "M_LOC_PROC_NOT_SUPP_BY_USER";
            case _M_QOS_NOT_ATTAINABLE:
                return "M_QOS_NOT_ATTAINABLE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 11
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static MobilityDiagnostic getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof MobilityDiagnostic)) {
            return false;
        }
        MobilityDiagnostic mobilityDiagnostic = (MobilityDiagnostic) o; 
        if(!(this.getValue() == mobilityDiagnostic.getValue())) {
            return false;
        }
        if (this.hashCode() != mobilityDiagnostic.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // MobilityDiagnostic

