//Source file: MobilityError.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Defines an error that is reported by one of the mobility services.
 *
 */
public final class MobilityError implements java.io.Serializable {

    private int _value;
    private static int _size = 7;
    private static MobilityError[] _array = new MobilityError[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private MobilityError(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * No error occurred while processing the request.
     */
    public static final int _M_OK =  0;

    /**
     * No error occurred while processing the request.
     */
    public static final MobilityError M_OK = new MobilityError(_M_OK);

    /**
     * System failure.
The request cannot be handled because of a general problem in the mobility service or the underlying network.
     */
    public static final int _M_SYSTEM_FAILURE =  1;

    /**
     * System failure.
The request cannot be handled because of a general problem in the mobility service or the underlying network.
     */
    public static final MobilityError M_SYSTEM_FAILURE = new MobilityError(_M_SYSTEM_FAILURE);

    /**
     * Unauthorised network,
The requesting network is not authorised to obtain the user's binding details, location or status.
     */
    public static final int _M_UNAUTHORIZED_NETWORK =  2;

    /**
     * Unauthorised network,
The requesting network is not authorised to obtain the user's binding details, location or status.
     */
    public static final MobilityError M_UNAUTHORIZED_NETWORK = new MobilityError(_M_UNAUTHORIZED_NETWORK);

    /**
     * Unauthorised application.
The application is not authorised to obtain the user's binding details, location or status.
     */
    public static final int _M_UNAUTHORIZED_APPLICATION =  3;

    /**
     * Unauthorised application.
The application is not authorised to obtain the user's binding details, location or status.
     */
    public static final MobilityError M_UNAUTHORIZED_APPLICATION = new MobilityError(_M_UNAUTHORIZED_APPLICATION);

    /**
     * Unknown subscriber.
The user is unknown, that is no such subscription exists.
     */
    public static final int _M_UNKNOWN_SUBSCRIBER =  4;

    /**
     * Unknown subscriber.
The user is unknown, that is no such subscription exists.
     */
    public static final MobilityError M_UNKNOWN_SUBSCRIBER = new MobilityError(_M_UNKNOWN_SUBSCRIBER);

    /**
     * Absent subscriber.
The user is currently not reachable.
     */
    public static final int _M_ABSENT_SUBSCRIBER =  5;

    /**
     * Absent subscriber.
The user is currently not reachable.
     */
    public static final MobilityError M_ABSENT_SUBSCRIBER = new MobilityError(_M_ABSENT_SUBSCRIBER);

    /**
     * Position method failure.
The mobility service failed to obtain the user's position.
     */
    public static final int _M_POSITION_METHOD_FAILURE =  6;

    /**
     * Position method failure.
The mobility service failed to obtain the user's position.
     */
    public static final MobilityError M_POSITION_METHOD_FAILURE = new MobilityError(_M_POSITION_METHOD_FAILURE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved MobilityError object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the MobilityError object
     */
    public String getValueText() {
        switch (_value) {
            case _M_OK:
                return "M_OK";
            case _M_SYSTEM_FAILURE:
                return "M_SYSTEM_FAILURE";
            case _M_UNAUTHORIZED_NETWORK:
                return "M_UNAUTHORIZED_NETWORK";
            case _M_UNAUTHORIZED_APPLICATION:
                return "M_UNAUTHORIZED_APPLICATION";
            case _M_UNKNOWN_SUBSCRIBER:
                return "M_UNKNOWN_SUBSCRIBER";
            case _M_ABSENT_SUBSCRIBER:
                return "M_ABSENT_SUBSCRIBER";
            case _M_POSITION_METHOD_FAILURE:
                return "M_POSITION_METHOD_FAILURE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 6
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static MobilityError getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof MobilityError)) {
            return false;
        }
        MobilityError mobilityError = (MobilityError) o; 
        if(!(this.getValue() == mobilityError.getValue())) {
            return false;
        }
        if (this.hashCode() != mobilityError.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // MobilityError

