//Source file: MobilityStopAssignmentData.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Defines the Sequence of Data Elements that specify a request to stop whole or parts of an assignment. Assignments are used for periodic or triggered reporting of a user's location or status.
Note that the parameter 'Users' is optional. If the parameter 'StopScope' is set to P_M_ALL_IN_ASSIGNMENT the parameter 'Users' is undefined. If the parameter 'StopScope' is set to P_M_SPECIFIED_USERS, then the assignment shall be stopped only for those users specified in the 'Users' list. 
 * 
 */
public final class MobilityStopAssignmentData implements java.io.Serializable {

    private int assignmentId;
    private org.csapi.jr.se.mm.MobilityStopScope stopScope;
    private org.csapi.jr.se.Address[] users;

    /**
     * Creates a new MobilityStopAssignmentData instance.
     */
    public MobilityStopAssignmentData () {}

    /**
     * Creates a new MobilityStopAssignmentData instance.
     * @param _assignmentId   Identity of the assignment that shall be stopped. 
     * @param _stopScope   Specify if only a part of the assignment or if all the assignment shall be stopped. 
     * @param _users   Optional parameter describing which users a stop request is addressing, when only a part of an assignment is to be stopped. 
     */
    public MobilityStopAssignmentData (int _assignmentId, org.csapi.jr.se.mm.MobilityStopScope _stopScope, org.csapi.jr.se.Address[] _users) {

        this.assignmentId = _assignmentId;
        this.stopScope = _stopScope;
        this.users = _users;
    }

    /**
     * This method returns a assignmentId.
     * 
     * @return a int value
     */
    public int getAssignmentId() {
        return assignmentId;
    }

    /**
     * This method returns a stopScope.
     * 
     * @return a org.csapi.jr.se.mm.MobilityStopScope value
     */
    public org.csapi.jr.se.mm.MobilityStopScope getStopScope() {
        return stopScope;
    }

    /**
     * This method returns a users.
     * 
     * @return a org.csapi.jr.se.Address[] value
     */
    public org.csapi.jr.se.Address[] getUsers() {
        return users;
    }


    /**
     * This method sets a assignmentId.
     */ 
    public void setAssignmentId(int assignmentId) {
        this.assignmentId = assignmentId;
    }

    /**
     * This method sets a stopScope.
     */ 
    public void setStopScope(org.csapi.jr.se.mm.MobilityStopScope stopScope) {
        this.stopScope = stopScope;
    }

    /**
     * This method sets a users.
     */ 
    public void setUsers(org.csapi.jr.se.Address[] users) {
        this.users = users;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof MobilityStopAssignmentData)) {
            return false;
        } 
        MobilityStopAssignmentData mobilityStopAssignmentData = (MobilityStopAssignmentData) o;
        if(!(this.users == mobilityStopAssignmentData.users))  {
            return false;
        }
        if(!(this.assignmentId == mobilityStopAssignmentData.assignmentId)) {
            return false;
        }
        if ((this.stopScope != null) && (mobilityStopAssignmentData.stopScope != null)) {
            if(!(this.stopScope.equals(mobilityStopAssignmentData.stopScope))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // MobilityStopAssignmentData

