//Source file: MobilityStopScope.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * This enumeration is used in requests to stop mobility reports that are sent from a mobility service to an application. 
 *
 */
public final class MobilityStopScope implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static MobilityStopScope[] _array = new MobilityStopScope[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private MobilityStopScope(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * The request concerns all users in an assignment.
     */
    public static final int _M_ALL_IN_ASSIGNMENT =  0;

    /**
     * The request concerns all users in an assignment.
     */
    public static final MobilityStopScope M_ALL_IN_ASSIGNMENT = new MobilityStopScope(_M_ALL_IN_ASSIGNMENT);

    /**
     * The request concerns only the users that are explicitly specified in a list.
     */
    public static final int _M_SPECIFIED_USERS =  1;

    /**
     * The request concerns only the users that are explicitly specified in a list.
     */
    public static final MobilityStopScope M_SPECIFIED_USERS = new MobilityStopScope(_M_SPECIFIED_USERS);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved MobilityStopScope object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the MobilityStopScope object
     */
    public String getValueText() {
        switch (_value) {
            case _M_ALL_IN_ASSIGNMENT:
                return "M_ALL_IN_ASSIGNMENT";
            case _M_SPECIFIED_USERS:
                return "M_SPECIFIED_USERS";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static MobilityStopScope getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof MobilityStopScope)) {
            return false;
        }
        MobilityStopScope mobilityStopScope = (MobilityStopScope) o; 
        if(!(this.getValue() == mobilityStopScope.getValue())) {
            return false;
        }
        if (this.hashCode() != mobilityStopScope.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // MobilityStopScope

