//Source file: UserLocationCamel.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Defines the Sequence of Data Elements that specify the location of a mobile telephony user. Note that if the StatusCode is indicating an error, then neither GeographicalPosition, Timestamp, VlrNumber, LocationNumber, CellIdOrLai nor their associated presence flags are defined. 
NOTE:	The location number is the number to the MSC or in rare cases the roaming number.
 * 
 */
public final class UserLocationCamel implements java.io.Serializable {

    private org.csapi.jr.se.Address userID;
    private org.csapi.jr.se.mm.MobilityError statusCode;
    private boolean geographicalPositionPresent;
    private org.csapi.jr.se.mm.GeographicalPosition geographicalPosition;
    private boolean timestampPresent;
    private String timestamp;
    private boolean vlrNumberPresent;
    private org.csapi.jr.se.Address vlrNumber;
    private boolean locationNumberPresent;
    private org.csapi.jr.se.Address locationNumber;
    private boolean cellIdOrLaiPresent;
    private String cellIdOrLai;

    /**
     * Creates a new UserLocationCamel instance.
     */
    public UserLocationCamel () {}

    /**
     * Creates a new UserLocationCamel instance.
     * @param _userID   The address of the user.
     * @param _statusCode   Indicator of error.
     * @param _geographicalPositionPresent   Flag indicating if the geographical position is present. 
     * @param _geographicalPosition   Specification of a position and an area of uncertainty. 
     * @param _timestampPresent   Flag indicating if the timestamp is present.
     * @param _timestamp   Timestamp indicating when the request was processed.
     * @param _vlrNumberPresent   Flag indicating if the VLR number is present.
     * @param _vlrNumber   Current VLR number for the user. 
     * @param _locationNumberPresent   Flag indicating if the location number is present.
     * @param _locationNumber   Current location number. 
     * @param _cellIdOrLaiPresent   Flag indicating if cell-id or LAI of the user is present.
     * @param _cellIdOrLai   Cell-id or LAI of the user. 
     */
    public UserLocationCamel (org.csapi.jr.se.Address _userID, org.csapi.jr.se.mm.MobilityError _statusCode, boolean _geographicalPositionPresent, org.csapi.jr.se.mm.GeographicalPosition _geographicalPosition, boolean _timestampPresent, String _timestamp, boolean _vlrNumberPresent, org.csapi.jr.se.Address _vlrNumber, boolean _locationNumberPresent, org.csapi.jr.se.Address _locationNumber, boolean _cellIdOrLaiPresent, String _cellIdOrLai) {

        this.userID = _userID;
        this.statusCode = _statusCode;
        this.geographicalPositionPresent = _geographicalPositionPresent;
        this.geographicalPosition = _geographicalPosition;
        this.timestampPresent = _timestampPresent;
        this.timestamp = _timestamp;
        this.vlrNumberPresent = _vlrNumberPresent;
        this.vlrNumber = _vlrNumber;
        this.locationNumberPresent = _locationNumberPresent;
        this.locationNumber = _locationNumber;
        this.cellIdOrLaiPresent = _cellIdOrLaiPresent;
        this.cellIdOrLai = _cellIdOrLai;
    }

    /**
     * This method returns a userID.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getUserID() {
        return userID;
    }

    /**
     * This method returns a statusCode.
     * 
     * @return a org.csapi.jr.se.mm.MobilityError value
     */
    public org.csapi.jr.se.mm.MobilityError getStatusCode() {
        return statusCode;
    }

    /**
     * This method returns a geographicalPositionPresent.
     * 
     * @return a boolean value
     */
    public boolean getGeographicalPositionPresent() {
        return geographicalPositionPresent;
    }

    /**
     * This method returns a geographicalPosition.
     * 
     * @return a org.csapi.jr.se.mm.GeographicalPosition value
     */
    public org.csapi.jr.se.mm.GeographicalPosition getGeographicalPosition() {
        return geographicalPosition;
    }

    /**
     * This method returns a timestampPresent.
     * 
     * @return a boolean value
     */
    public boolean getTimestampPresent() {
        return timestampPresent;
    }

    /**
     * This method returns a timestamp.
     * 
     * @return a String value
     */
    public String getTimestamp() {
        return timestamp;
    }

    /**
     * This method returns a vlrNumberPresent.
     * 
     * @return a boolean value
     */
    public boolean getVlrNumberPresent() {
        return vlrNumberPresent;
    }

    /**
     * This method returns a vlrNumber.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getVlrNumber() {
        return vlrNumber;
    }

    /**
     * This method returns a locationNumberPresent.
     * 
     * @return a boolean value
     */
    public boolean getLocationNumberPresent() {
        return locationNumberPresent;
    }

    /**
     * This method returns a locationNumber.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getLocationNumber() {
        return locationNumber;
    }

    /**
     * This method returns a cellIdOrLaiPresent.
     * 
     * @return a boolean value
     */
    public boolean getCellIdOrLaiPresent() {
        return cellIdOrLaiPresent;
    }

    /**
     * This method returns a cellIdOrLai.
     * 
     * @return a String value
     */
    public String getCellIdOrLai() {
        return cellIdOrLai;
    }


    /**
     * This method sets a userID.
     */ 
    public void setUserID(org.csapi.jr.se.Address userID) {
        this.userID = userID;
    }

    /**
     * This method sets a statusCode.
     */ 
    public void setStatusCode(org.csapi.jr.se.mm.MobilityError statusCode) {
        this.statusCode = statusCode;
    }

    /**
     * This method sets a geographicalPositionPresent.
     */ 
    public void setGeographicalPositionPresent(boolean geographicalPositionPresent) {
        this.geographicalPositionPresent = geographicalPositionPresent;
    }

    /**
     * This method sets a geographicalPosition.
     */ 
    public void setGeographicalPosition(org.csapi.jr.se.mm.GeographicalPosition geographicalPosition) {
        this.geographicalPosition = geographicalPosition;
    }

    /**
     * This method sets a timestampPresent.
     */ 
    public void setTimestampPresent(boolean timestampPresent) {
        this.timestampPresent = timestampPresent;
    }

    /**
     * This method sets a timestamp.
     */ 
    public void setTimestamp(String timestamp) {
        this.timestamp = timestamp;
    }

    /**
     * This method sets a vlrNumberPresent.
     */ 
    public void setVlrNumberPresent(boolean vlrNumberPresent) {
        this.vlrNumberPresent = vlrNumberPresent;
    }

    /**
     * This method sets a vlrNumber.
     */ 
    public void setVlrNumber(org.csapi.jr.se.Address vlrNumber) {
        this.vlrNumber = vlrNumber;
    }

    /**
     * This method sets a locationNumberPresent.
     */ 
    public void setLocationNumberPresent(boolean locationNumberPresent) {
        this.locationNumberPresent = locationNumberPresent;
    }

    /**
     * This method sets a locationNumber.
     */ 
    public void setLocationNumber(org.csapi.jr.se.Address locationNumber) {
        this.locationNumber = locationNumber;
    }

    /**
     * This method sets a cellIdOrLaiPresent.
     */ 
    public void setCellIdOrLaiPresent(boolean cellIdOrLaiPresent) {
        this.cellIdOrLaiPresent = cellIdOrLaiPresent;
    }

    /**
     * This method sets a cellIdOrLai.
     */ 
    public void setCellIdOrLai(String cellIdOrLai) {
        this.cellIdOrLai = cellIdOrLai;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UserLocationCamel)) {
            return false;
        } 
        UserLocationCamel userLocationCamel = (UserLocationCamel) o;
        if ((this.userID != null) && (userLocationCamel.userID != null)) {
            if(!(this.userID.equals(userLocationCamel.userID))) {
                return false;
            }
        }
        if ((this.statusCode != null) && (userLocationCamel.statusCode != null)) {
            if(!(this.statusCode.equals(userLocationCamel.statusCode))) {
                return false;
            }
        }
        if(!(this.geographicalPositionPresent == userLocationCamel.geographicalPositionPresent)) {
            return false;
        }
        if ((this.geographicalPosition != null) && (userLocationCamel.geographicalPosition != null)) {
            if(!(this.geographicalPosition.equals(userLocationCamel.geographicalPosition))) {
                return false;
            }
        }
        if(!(this.timestampPresent == userLocationCamel.timestampPresent)) {
            return false;
        }
        if(!(this.timestamp == userLocationCamel.timestamp))  {
            return false;
        }
        if(!(this.vlrNumberPresent == userLocationCamel.vlrNumberPresent)) {
            return false;
        }
        if ((this.vlrNumber != null) && (userLocationCamel.vlrNumber != null)) {
            if(!(this.vlrNumber.equals(userLocationCamel.vlrNumber))) {
                return false;
            }
        }
        if(!(this.locationNumberPresent == userLocationCamel.locationNumberPresent)) {
            return false;
        }
        if ((this.locationNumber != null) && (userLocationCamel.locationNumber != null)) {
            if(!(this.locationNumber.equals(userLocationCamel.locationNumber))) {
                return false;
            }
        }
        if(!(this.cellIdOrLaiPresent == userLocationCamel.cellIdOrLaiPresent)) {
            return false;
        }
        if(!(this.cellIdOrLai == userLocationCamel.cellIdOrLai))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UserLocationCamel

