//Source file: UserLocationEmergency.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Defines the Sequence of Data Elements that specify the identity and location of an emergency service user.
The emergency service user is identified by a combination of UserID, NaESRD, NaESRK and IMEI.
NaESRD, NaESRK and IMEI may be provided, if the emergency service user has originated the emergency service call in North America.
The horizontal location is defined by an 'ellipsoid point with uncertainty ellipse' (see TpUlExtendedData).
 * 
 */
public final class UserLocationEmergency implements java.io.Serializable {

    private org.csapi.jr.se.mm.MobilityError statusCode;
    private boolean userIdPresent;
    private org.csapi.jr.se.Address userId;
    private boolean naEsrdPresent;
    private String naEsrd;
    private boolean naEsrkPresent;
    private String naEsrk;
    private boolean imeiPresent;
    private String imei;
    private org.csapi.jr.se.mm.UserLocationEmergencyTrigger triggeringEvent;
    private boolean geographicalPositionPresent;
    private org.csapi.jr.se.mm.GeographicalPosition geographicalPosition;
    private boolean altitudePresent;
    private float altitude;
    private float uncertaintyAltitude;
    private boolean timestampPresent;
    private String timestamp;
    private String usedLocationMethod;

    /**
     * Creates a new UserLocationEmergency instance.
     */
    public UserLocationEmergency () {}

    /**
     * Creates a new UserLocationEmergency instance.
     * @param _statusCode   Indicator of error.
     * @param _userIdPresent   Flag indicating if the user address is present.
     * @param _userId   The user address. 
     * @param _naEsrdPresent   Flag indicating if the NaESRD is present.
     * @param _naEsrd   Current NaESRD for the user.
     * @param _naEsrkPresent   Flag indicating if the NaESRK is present.
     * @param _naEsrk   Current NaESRK for the user.
     * @param _imeiPresent   Flag indicating if the IMEI is present.
     * @param _imei   IMEI for the user.
     * @param _triggeringEvent   The reason for this location report. 
     * @param _geographicalPositionPresent   Flag indicating if the geographical position is present.
     * @param _geographicalPosition   Specification of a position and an area of uncertainty.
     * @param _altitudePresent   Flag indicating if the altitude is present.
     * @param _altitude   Decimal altitude in meters.
     * @param _uncertaintyAltitude   Uncertainty of the altitude.
     * @param _timestampPresent   Flag indicating if a timestamp is present.
     * @param _timestamp   Timestamp indicating when the request was processed.
     * @param _usedLocationMethod   Specifying which location method was used.
     */
    public UserLocationEmergency (org.csapi.jr.se.mm.MobilityError _statusCode, boolean _userIdPresent, org.csapi.jr.se.Address _userId, boolean _naEsrdPresent, String _naEsrd, boolean _naEsrkPresent, String _naEsrk, boolean _imeiPresent, String _imei, org.csapi.jr.se.mm.UserLocationEmergencyTrigger _triggeringEvent, boolean _geographicalPositionPresent, org.csapi.jr.se.mm.GeographicalPosition _geographicalPosition, boolean _altitudePresent, float _altitude, float _uncertaintyAltitude, boolean _timestampPresent, String _timestamp, String _usedLocationMethod) {

        this.statusCode = _statusCode;
        this.userIdPresent = _userIdPresent;
        this.userId = _userId;
        this.naEsrdPresent = _naEsrdPresent;
        this.naEsrd = _naEsrd;
        this.naEsrkPresent = _naEsrkPresent;
        this.naEsrk = _naEsrk;
        this.imeiPresent = _imeiPresent;
        this.imei = _imei;
        this.triggeringEvent = _triggeringEvent;
        this.geographicalPositionPresent = _geographicalPositionPresent;
        this.geographicalPosition = _geographicalPosition;
        this.altitudePresent = _altitudePresent;
        this.altitude = _altitude;
        this.uncertaintyAltitude = _uncertaintyAltitude;
        this.timestampPresent = _timestampPresent;
        this.timestamp = _timestamp;
        this.usedLocationMethod = _usedLocationMethod;
    }

    /**
     * This method returns a statusCode.
     * 
     * @return a org.csapi.jr.se.mm.MobilityError value
     */
    public org.csapi.jr.se.mm.MobilityError getStatusCode() {
        return statusCode;
    }

    /**
     * This method returns a userIdPresent.
     * 
     * @return a boolean value
     */
    public boolean getUserIdPresent() {
        return userIdPresent;
    }

    /**
     * This method returns a userId.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getUserId() {
        return userId;
    }

    /**
     * This method returns a naEsrdPresent.
     * 
     * @return a boolean value
     */
    public boolean getNaEsrdPresent() {
        return naEsrdPresent;
    }

    /**
     * This method returns a naEsrd.
     * 
     * @return a String value
     */
    public String getNaEsrd() {
        return naEsrd;
    }

    /**
     * This method returns a naEsrkPresent.
     * 
     * @return a boolean value
     */
    public boolean getNaEsrkPresent() {
        return naEsrkPresent;
    }

    /**
     * This method returns a naEsrk.
     * 
     * @return a String value
     */
    public String getNaEsrk() {
        return naEsrk;
    }

    /**
     * This method returns a imeiPresent.
     * 
     * @return a boolean value
     */
    public boolean getImeiPresent() {
        return imeiPresent;
    }

    /**
     * This method returns a imei.
     * 
     * @return a String value
     */
    public String getImei() {
        return imei;
    }

    /**
     * This method returns a triggeringEvent.
     * 
     * @return a org.csapi.jr.se.mm.UserLocationEmergencyTrigger value
     */
    public org.csapi.jr.se.mm.UserLocationEmergencyTrigger getTriggeringEvent() {
        return triggeringEvent;
    }

    /**
     * This method returns a geographicalPositionPresent.
     * 
     * @return a boolean value
     */
    public boolean getGeographicalPositionPresent() {
        return geographicalPositionPresent;
    }

    /**
     * This method returns a geographicalPosition.
     * 
     * @return a org.csapi.jr.se.mm.GeographicalPosition value
     */
    public org.csapi.jr.se.mm.GeographicalPosition getGeographicalPosition() {
        return geographicalPosition;
    }

    /**
     * This method returns a altitudePresent.
     * 
     * @return a boolean value
     */
    public boolean getAltitudePresent() {
        return altitudePresent;
    }

    /**
     * This method returns a altitude.
     * 
     * @return a float value
     */
    public float getAltitude() {
        return altitude;
    }

    /**
     * This method returns a uncertaintyAltitude.
     * 
     * @return a float value
     */
    public float getUncertaintyAltitude() {
        return uncertaintyAltitude;
    }

    /**
     * This method returns a timestampPresent.
     * 
     * @return a boolean value
     */
    public boolean getTimestampPresent() {
        return timestampPresent;
    }

    /**
     * This method returns a timestamp.
     * 
     * @return a String value
     */
    public String getTimestamp() {
        return timestamp;
    }

    /**
     * This method returns a usedLocationMethod.
     * 
     * @return a String value
     */
    public String getUsedLocationMethod() {
        return usedLocationMethod;
    }


    /**
     * This method sets a statusCode.
     */ 
    public void setStatusCode(org.csapi.jr.se.mm.MobilityError statusCode) {
        this.statusCode = statusCode;
    }

    /**
     * This method sets a userIdPresent.
     */ 
    public void setUserIdPresent(boolean userIdPresent) {
        this.userIdPresent = userIdPresent;
    }

    /**
     * This method sets a userId.
     */ 
    public void setUserId(org.csapi.jr.se.Address userId) {
        this.userId = userId;
    }

    /**
     * This method sets a naEsrdPresent.
     */ 
    public void setNaEsrdPresent(boolean naEsrdPresent) {
        this.naEsrdPresent = naEsrdPresent;
    }

    /**
     * This method sets a naEsrd.
     */ 
    public void setNaEsrd(String naEsrd) {
        this.naEsrd = naEsrd;
    }

    /**
     * This method sets a naEsrkPresent.
     */ 
    public void setNaEsrkPresent(boolean naEsrkPresent) {
        this.naEsrkPresent = naEsrkPresent;
    }

    /**
     * This method sets a naEsrk.
     */ 
    public void setNaEsrk(String naEsrk) {
        this.naEsrk = naEsrk;
    }

    /**
     * This method sets a imeiPresent.
     */ 
    public void setImeiPresent(boolean imeiPresent) {
        this.imeiPresent = imeiPresent;
    }

    /**
     * This method sets a imei.
     */ 
    public void setImei(String imei) {
        this.imei = imei;
    }

    /**
     * This method sets a triggeringEvent.
     */ 
    public void setTriggeringEvent(org.csapi.jr.se.mm.UserLocationEmergencyTrigger triggeringEvent) {
        this.triggeringEvent = triggeringEvent;
    }

    /**
     * This method sets a geographicalPositionPresent.
     */ 
    public void setGeographicalPositionPresent(boolean geographicalPositionPresent) {
        this.geographicalPositionPresent = geographicalPositionPresent;
    }

    /**
     * This method sets a geographicalPosition.
     */ 
    public void setGeographicalPosition(org.csapi.jr.se.mm.GeographicalPosition geographicalPosition) {
        this.geographicalPosition = geographicalPosition;
    }

    /**
     * This method sets a altitudePresent.
     */ 
    public void setAltitudePresent(boolean altitudePresent) {
        this.altitudePresent = altitudePresent;
    }

    /**
     * This method sets a altitude.
     */ 
    public void setAltitude(float altitude) {
        this.altitude = altitude;
    }

    /**
     * This method sets a uncertaintyAltitude.
     */ 
    public void setUncertaintyAltitude(float uncertaintyAltitude) {
        this.uncertaintyAltitude = uncertaintyAltitude;
    }

    /**
     * This method sets a timestampPresent.
     */ 
    public void setTimestampPresent(boolean timestampPresent) {
        this.timestampPresent = timestampPresent;
    }

    /**
     * This method sets a timestamp.
     */ 
    public void setTimestamp(String timestamp) {
        this.timestamp = timestamp;
    }

    /**
     * This method sets a usedLocationMethod.
     */ 
    public void setUsedLocationMethod(String usedLocationMethod) {
        this.usedLocationMethod = usedLocationMethod;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UserLocationEmergency)) {
            return false;
        } 
        UserLocationEmergency userLocationEmergency = (UserLocationEmergency) o;
        if ((this.statusCode != null) && (userLocationEmergency.statusCode != null)) {
            if(!(this.statusCode.equals(userLocationEmergency.statusCode))) {
                return false;
            }
        }
        if(!(this.userIdPresent == userLocationEmergency.userIdPresent)) {
            return false;
        }
        if ((this.userId != null) && (userLocationEmergency.userId != null)) {
            if(!(this.userId.equals(userLocationEmergency.userId))) {
                return false;
            }
        }
        if(!(this.naEsrdPresent == userLocationEmergency.naEsrdPresent)) {
            return false;
        }
        if(!(this.naEsrd == userLocationEmergency.naEsrd))  {
            return false;
        }
        if(!(this.naEsrkPresent == userLocationEmergency.naEsrkPresent)) {
            return false;
        }
        if(!(this.naEsrk == userLocationEmergency.naEsrk))  {
            return false;
        }
        if(!(this.imeiPresent == userLocationEmergency.imeiPresent)) {
            return false;
        }
        if(!(this.imei == userLocationEmergency.imei))  {
            return false;
        }
        if ((this.triggeringEvent != null) && (userLocationEmergency.triggeringEvent != null)) {
            if(!(this.triggeringEvent.equals(userLocationEmergency.triggeringEvent))) {
                return false;
            }
        }
        if(!(this.geographicalPositionPresent == userLocationEmergency.geographicalPositionPresent)) {
            return false;
        }
        if ((this.geographicalPosition != null) && (userLocationEmergency.geographicalPosition != null)) {
            if(!(this.geographicalPosition.equals(userLocationEmergency.geographicalPosition))) {
                return false;
            }
        }
        if(!(this.altitudePresent == userLocationEmergency.altitudePresent)) {
            return false;
        }
        if(!(this.altitude == userLocationEmergency.altitude)) {
            return false;
        }
        if(!(this.uncertaintyAltitude == userLocationEmergency.uncertaintyAltitude)) {
            return false;
        }
        if(!(this.timestampPresent == userLocationEmergency.timestampPresent)) {
            return false;
        }
        if(!(this.timestamp == userLocationEmergency.timestamp))  {
            return false;
        }
        if ((this.usedLocationMethod != null) && (userLocationEmergency.usedLocationMethod != null)) {
            if(!(this.usedLocationMethod.equals(userLocationEmergency.usedLocationMethod)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UserLocationEmergency

