//Source file: UserLocationEmergencyRequest.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Defines the Sequence of Data Elements that specify the request for the location of an emergency service user. The emergency service user is identified by a combination of user address, NaESRD, NaESRK and IMEI. NaESRD, NaESRK and IMEI may be provided, if the emergency service user has originated the emergency service call in North America. 
 * 
 */
public final class UserLocationEmergencyRequest implements java.io.Serializable {

    private boolean userAddressPresent;
    private org.csapi.jr.se.Address userAddress;
    private boolean naEsrdPresent;
    private String naEsrd;
    private boolean naEsrkPresent;
    private String naEsrk;
    private boolean imeiPresent;
    private String imei;
    private org.csapi.jr.se.mm.LocationRequest locationReq;

    /**
     * Creates a new UserLocationEmergencyRequest instance.
     */
    public UserLocationEmergencyRequest () {}

    /**
     * Creates a new UserLocationEmergencyRequest instance.
     * @param _userAddressPresent   Flag indicating if the user address is present.
     * @param _userAddress   The address of the user.
     * @param _naEsrdPresent   Flag indicating if the NaESRD is present.
     * @param _naEsrd   Current NaESRD for the user.
     * @param _naEsrkPresent   Flag indicating if the NaESRK is present.
     * @param _naEsrk   Current NaESRK for the user.
     * @param _imeiPresent   Flag indicating if the IMEI is present.
     * @param _imei   IMEI for the user.
     * @param _locationReq   The actual location request. 
     */
    public UserLocationEmergencyRequest (boolean _userAddressPresent, org.csapi.jr.se.Address _userAddress, boolean _naEsrdPresent, String _naEsrd, boolean _naEsrkPresent, String _naEsrk, boolean _imeiPresent, String _imei, org.csapi.jr.se.mm.LocationRequest _locationReq) {

        this.userAddressPresent = _userAddressPresent;
        this.userAddress = _userAddress;
        this.naEsrdPresent = _naEsrdPresent;
        this.naEsrd = _naEsrd;
        this.naEsrkPresent = _naEsrkPresent;
        this.naEsrk = _naEsrk;
        this.imeiPresent = _imeiPresent;
        this.imei = _imei;
        this.locationReq = _locationReq;
    }

    /**
     * This method returns a userAddressPresent.
     * 
     * @return a boolean value
     */
    public boolean getUserAddressPresent() {
        return userAddressPresent;
    }

    /**
     * This method returns a userAddress.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getUserAddress() {
        return userAddress;
    }

    /**
     * This method returns a naEsrdPresent.
     * 
     * @return a boolean value
     */
    public boolean getNaEsrdPresent() {
        return naEsrdPresent;
    }

    /**
     * This method returns a naEsrd.
     * 
     * @return a String value
     */
    public String getNaEsrd() {
        return naEsrd;
    }

    /**
     * This method returns a naEsrkPresent.
     * 
     * @return a boolean value
     */
    public boolean getNaEsrkPresent() {
        return naEsrkPresent;
    }

    /**
     * This method returns a naEsrk.
     * 
     * @return a String value
     */
    public String getNaEsrk() {
        return naEsrk;
    }

    /**
     * This method returns a imeiPresent.
     * 
     * @return a boolean value
     */
    public boolean getImeiPresent() {
        return imeiPresent;
    }

    /**
     * This method returns a imei.
     * 
     * @return a String value
     */
    public String getImei() {
        return imei;
    }

    /**
     * This method returns a locationReq.
     * 
     * @return a org.csapi.jr.se.mm.LocationRequest value
     */
    public org.csapi.jr.se.mm.LocationRequest getLocationReq() {
        return locationReq;
    }


    /**
     * This method sets a userAddressPresent.
     */ 
    public void setUserAddressPresent(boolean userAddressPresent) {
        this.userAddressPresent = userAddressPresent;
    }

    /**
     * This method sets a userAddress.
     */ 
    public void setUserAddress(org.csapi.jr.se.Address userAddress) {
        this.userAddress = userAddress;
    }

    /**
     * This method sets a naEsrdPresent.
     */ 
    public void setNaEsrdPresent(boolean naEsrdPresent) {
        this.naEsrdPresent = naEsrdPresent;
    }

    /**
     * This method sets a naEsrd.
     */ 
    public void setNaEsrd(String naEsrd) {
        this.naEsrd = naEsrd;
    }

    /**
     * This method sets a naEsrkPresent.
     */ 
    public void setNaEsrkPresent(boolean naEsrkPresent) {
        this.naEsrkPresent = naEsrkPresent;
    }

    /**
     * This method sets a naEsrk.
     */ 
    public void setNaEsrk(String naEsrk) {
        this.naEsrk = naEsrk;
    }

    /**
     * This method sets a imeiPresent.
     */ 
    public void setImeiPresent(boolean imeiPresent) {
        this.imeiPresent = imeiPresent;
    }

    /**
     * This method sets a imei.
     */ 
    public void setImei(String imei) {
        this.imei = imei;
    }

    /**
     * This method sets a locationReq.
     */ 
    public void setLocationReq(org.csapi.jr.se.mm.LocationRequest locationReq) {
        this.locationReq = locationReq;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UserLocationEmergencyRequest)) {
            return false;
        } 
        UserLocationEmergencyRequest userLocationEmergencyRequest = (UserLocationEmergencyRequest) o;
        if(!(this.userAddressPresent == userLocationEmergencyRequest.userAddressPresent)) {
            return false;
        }
        if ((this.userAddress != null) && (userLocationEmergencyRequest.userAddress != null)) {
            if(!(this.userAddress.equals(userLocationEmergencyRequest.userAddress))) {
                return false;
            }
        }
        if(!(this.naEsrdPresent == userLocationEmergencyRequest.naEsrdPresent)) {
            return false;
        }
        if(!(this.naEsrd == userLocationEmergencyRequest.naEsrd))  {
            return false;
        }
        if(!(this.naEsrkPresent == userLocationEmergencyRequest.naEsrkPresent)) {
            return false;
        }
        if(!(this.naEsrk == userLocationEmergencyRequest.naEsrk))  {
            return false;
        }
        if(!(this.imeiPresent == userLocationEmergencyRequest.imeiPresent)) {
            return false;
        }
        if(!(this.imei == userLocationEmergencyRequest.imei))  {
            return false;
        }
        if ((this.locationReq != null) && (userLocationEmergencyRequest.locationReq != null)) {
            if(!(this.locationReq.equals(userLocationEmergencyRequest.locationReq))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UserLocationEmergencyRequest

