//Source file: UserLocationExtended.java
//Date: March 2007
//Mobility Interfaces and Data Types for 1st draft ETSI ES 204 915-06 V1.1.1, DES/TISPAN-01032-06-OSA, Parlay 6.0

package org.csapi.jr.se.mm;

/**
 * Defines the Sequence of Data Elements that specify the identity and location(s) of a user (extended format). In general the data element Locations will contain only one location, but in case of IP-telephony users this data element might continue several locations (the locations of all communication end-points, where the user is currently registered).
 * 
 */
public final class UserLocationExtended implements java.io.Serializable {

    private org.csapi.jr.se.Address userID;
    private org.csapi.jr.se.mm.MobilityError statusCode;
    private org.csapi.jr.se.mm.UlExtendedData[] locations;

    /**
     * Creates a new UserLocationExtended instance.
     */
    public UserLocationExtended () {}

    /**
     * Creates a new UserLocationExtended instance.
     * @param _userID   The user address.
     * @param _statusCode   Indicator of error.
     * @param _locations   Optional list of locations. If StatusCode is indicating an error, this value is undefined. 
     */
    public UserLocationExtended (org.csapi.jr.se.Address _userID, org.csapi.jr.se.mm.MobilityError _statusCode, org.csapi.jr.se.mm.UlExtendedData[] _locations) {

        this.userID = _userID;
        this.statusCode = _statusCode;
        this.locations = _locations;
    }

    /**
     * This method returns a userID.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getUserID() {
        return userID;
    }

    /**
     * This method returns a statusCode.
     * 
     * @return a org.csapi.jr.se.mm.MobilityError value
     */
    public org.csapi.jr.se.mm.MobilityError getStatusCode() {
        return statusCode;
    }

    /**
     * This method returns a locations.
     * 
     * @return a org.csapi.jr.se.mm.UlExtendedData[] value
     */
    public org.csapi.jr.se.mm.UlExtendedData[] getLocations() {
        return locations;
    }


    /**
     * This method sets a userID.
     */ 
    public void setUserID(org.csapi.jr.se.Address userID) {
        this.userID = userID;
    }

    /**
     * This method sets a statusCode.
     */ 
    public void setStatusCode(org.csapi.jr.se.mm.MobilityError statusCode) {
        this.statusCode = statusCode;
    }

    /**
     * This method sets a locations.
     */ 
    public void setLocations(org.csapi.jr.se.mm.UlExtendedData[] locations) {
        this.locations = locations;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UserLocationExtended)) {
            return false;
        } 
        UserLocationExtended userLocationExtended = (UserLocationExtended) o;
        if ((this.userID != null) && (userLocationExtended.userID != null)) {
            if(!(this.userID.equals(userLocationExtended.userID))) {
                return false;
            }
        }
        if ((this.statusCode != null) && (userLocationExtended.statusCode != null)) {
            if(!(this.statusCode.equals(userLocationExtended.statusCode))) {
                return false;
            }
        }
        if(!(this.locations == userLocationExtended.locations))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UserLocationExtended

